pub fn kill_stake<T: Config>(who: &T::AccountId) -> DispatchResultExpand description
Release all staked amount to who.
Fails if there are consumers left on who that restricts it from being reaped.
pub fn kill_stake<T: Config>(who: &T::AccountId) -> DispatchResultRelease all staked amount to who.
Fails if there are consumers left on who that restricts it from being reaped.